@@ -36,7 +36,7 @@ namespace
 bool isDirHidden(QDir& dir)
 {
 #ifdef __unix__
-    return dir.absolutePath().contains("/.");
+    return dir.absolutePath().contains(QLatin1String("/."));
 #else
     if (QFileInfo(dir.path()).isHidden())
         return true;
@@ -52,7 +52,7 @@ using namespace Baloo;
 
 FileIndexerConfig::FileIndexerConfig(QObject* parent)
     : QObject(parent)
-    , m_config("baloofilerc", KConfig::SimpleConfig)
+    , m_config(QLatin1String("baloofilerc"), KConfig::SimpleConfig)
     , m_indexHidden(false)
 {
     KDirWatch* dirWatch = KDirWatch::self();
@@ -172,7 +172,7 @@ bool FileIndexerConfig::shouldFolderBeIndexed(const QString& path) const
 
         // check the exclude filters for all components of the path
         // after folder
-        const QStringList pathComponents = path.mid(folder.count()).split('/', QString::SkipEmptyParts);
+        const QStringList pathComponents = path.mid(folder.count()).split(QLatin1Char('/'), QString::SkipEmptyParts);
         Q_FOREACH (const QString& c, pathComponents) {
             if (!shouldFileBeIndexed(c)) {
                 return false;
@@ -234,8 +234,8 @@ bool alreadyExcluded(const QList<QPair<QString, bool> >& folders, const QString&
     bool included = false;
     for (int i = 0; i < folders.count(); ++i) {
         QString path = QUrl(folders[i].first).path();
-        if (!path.endsWith('/'))
-            path.append('/');
+        if (!path.endsWith(QLatin1Char('/')))
+            path.append(QLatin1Char('/'));
 
         if (f != folders[i].first && f.startsWith(path)) {
             included = folders[i].second;
@@ -326,7 +326,7 @@ bool FileIndexerConfig::buildFolderCache()
     QSet<QString> includeSet = includeFoldersPlain.toSet();
     QSet<QString> excludeSet = excludeFoldersPlain.toSet();
 
-    Entry& generalEntry = m_entries[ "General" ];
+    Entry& generalEntry = m_entries[ QLatin1String("General") ];
     fillIncludeFolderChanges(generalEntry, includeSet, &includeAdded, &includeRemoved);
     fillExcludeFolderChanges(generalEntry, excludeSet, &excludeAdded, &excludeRemoved);
 
@@ -338,7 +338,7 @@ bool FileIndexerConfig::buildFolderCache()
     //
     QStringList groupList = m_config.groupList();
     Q_FOREACH (const QString& groupName, groupList) {
-        if (!groupName.startsWith("Device-"))
+        if (!groupName.startsWith(QLatin1String("Device-")))
             continue;
 
         KConfigGroup group = m_config.group(groupName);
