@@ -21,7 +21,7 @@
 #include "indexingqueue.h"
 
 #include <QtCore/QTimer>
-#include <KDebug>
+#include <QDebug>
 
 using namespace Baloo;
 
@@ -106,3 +106,8 @@ void IndexingQueue::doResume()
 void IndexingQueue::doSuspend()
 {
 }
+
+bool IndexingQueue::isSuspended() const
+{
+    return m_suspended;
+}
