@@ -90,14 +90,14 @@ void FileFetchJob::doStart()
         const QString& url = file.url();
         if (url.size() && !QFile::exists(url)) {
             setError(Error_FileDoesNotExist);
-            setErrorText("File " + url + " does not exist");
+            setErrorText(QLatin1String("File ") + url + QLatin1String(" does not exist"));
             emitResult();
             return;
         }
 
         if (file.id().size() && !file.id().startsWith("file")) {
             setError(Error_InvalidId);
-            setErrorText("Invalid Id " + QString::fromUtf8(file.id()));
+            setErrorText(QLatin1String("Invalid Id ") + QString::fromUtf8(file.id()));
             emitResult();
             return;
         }
@@ -121,8 +121,8 @@ void FileFetchJob::doStart()
         file.setUrl(fileMap.url());
 
         // Fetch data from Xapian
-        Xapian::Database db(fileIndexDbPath());
         try {
+            Xapian::Database db(fileIndexDbPath());
             Xapian::Document doc = db.get_document(id);
 
             std::string docData = doc.get_data();
@@ -139,6 +139,9 @@ void FileFetchJob::doStart()
         catch (const Xapian::InvalidArgumentError& err) {
             qWarning() << err.get_msg().c_str();
         }
+        catch (const Xapian::Error& err) {
+            qWarning() << "Xapian error of type" << err.get_type() << ":" << err.get_msg().c_str();
+        }
 
         d->fetchUserMetadata(file);
         Q_EMIT fileReceived(file);
@@ -154,7 +157,7 @@ void FileFetchJob::Private::fetchUserMetadata(File& file)
     QString comment = customFileMetaData(url, QLatin1String("user.xdg.comment"));
 
     file.setRating(rating.toInt());
-    file.setTags(tags.split(',', QString::SkipEmptyParts));
+    file.setTags(tags.split(QLatin1Char(','), QString::SkipEmptyParts));
     file.setUserComment(comment);
 }
 
