@@ -27,7 +27,7 @@
 #include <QSqlError>
 #include <QStringList>
 
-#include <KDebug>
+#include <QDebug>
 
 using namespace Baloo;
 
@@ -45,9 +45,9 @@ MetadataMover::~MetadataMover()
 
 void MetadataMover::moveFileMetadata(const QString& from, const QString& to)
 {
-//    kDebug() << from << to;
-    Q_ASSERT(!from.isEmpty() && from != "/");
-    Q_ASSERT(!to.isEmpty() && to != "/");
+//    qDebug() << from << to;
+    Q_ASSERT(!from.isEmpty() && from != QLatin1String("/"));
+    Q_ASSERT(!to.isEmpty() && to != QLatin1String("/"));
 
     // We do NOT get deleted messages for overwritten files! Thus, we
     // have to remove all metadata for overwritten files first.
@@ -59,14 +59,14 @@ void MetadataMover::moveFileMetadata(const QString& from, const QString& to)
 
 void MetadataMover::removeFileMetadata(const QString& file)
 {
-    Q_ASSERT(!file.isEmpty() && file != "/");
+    Q_ASSERT(!file.isEmpty() && file != QLatin1String("/"));
     removeFileMetadata(QStringList() << file);
 }
 
 
 void MetadataMover::removeFileMetadata(const QStringList& files)
 {
-    kDebug() << files;
+    qDebug() << files;
 
     Q_FOREACH (const QString& file, files) {
         removeMetadata(file);
@@ -77,7 +77,7 @@ void MetadataMover::removeFileMetadata(const QStringList& files)
 void MetadataMover::removeMetadata(const QString& url)
 {
     if (url.isEmpty()) {
-        kDebug() << "empty path. Looks like a bug somewhere...";
+        qDebug() << "empty path. Looks like a bug somewhere...";
         return;
     }
 
@@ -85,10 +85,10 @@ void MetadataMover::removeMetadata(const QString& url)
     file.fetch(m_db->sqlDatabase());
 
     QSqlQuery query(m_db->sqlDatabase());
-    query.prepare("delete from files where url = ?");
+    query.prepare(QLatin1String("delete from files where url = ?"));
     query.addBindValue(url);
     if (!query.exec()) {
-        kError() << query.lastError().text();
+        qWarning() << query.lastError().text();
     }
 
     if (file.id())
@@ -98,25 +98,25 @@ void MetadataMover::removeMetadata(const QString& url)
 
 void MetadataMover::updateMetadata(const QString& from, const QString& to)
 {
-    kDebug() << from << "->" << to;
+    qDebug() << from << "->" << to;
     if (from.isEmpty() || to.isEmpty()) {
-        kError() << "Paths Empty - File a bug" << from << to;
+        qWarning() << "Paths Empty - File a bug" << from << to;
         return;
     }
 
-    Q_ASSERT(from[from.size()-1] != '/');
-    Q_ASSERT(to[to.size()-1] != '/');
+    Q_ASSERT(from[from.size()-1] != QLatin1Char('/'));
+    Q_ASSERT(to[to.size()-1] != QLatin1Char('/'));
 
     FileMapping fromFile(from);
     fromFile.fetch(m_db->sqlDatabase());
 
     if (fromFile.fetch(m_db->sqlDatabase())) {
         QSqlQuery q(m_db->sqlDatabase());
-        q.prepare("update files set url = ? where id = ?");
+        q.prepare(QLatin1String("update files set url = ? where id = ?"));
         q.addBindValue(to);
         q.addBindValue(fromFile.id());
         if (!q.exec())
-            kError() << q.lastError().text();
+            qWarning() << q.lastError().text();
     }
 
     if (!fromFile.id()) {
@@ -145,20 +145,18 @@ void MetadataMover::updateMetadata(const QString& from, const QString& to)
     // Temporary workaround because either sqlite3_prepare16_v2 seems to be buggy
     // or the qt sqlite driver is not calling it properly
     //
-    QString queryStr("update files set url = '");
+    QString queryStr(QLatin1String("update files set url = '"));
     queryStr.append(to);
-    queryStr.append("' || substr(url, ");
+    queryStr.append(QLatin1String("' || substr(url, "));
     queryStr.append(QString::number(from.size() + 1));
-    queryStr.append(") where url like '");
+    queryStr.append(QLatin1String(") where url like '"));
     queryStr.append(from);
-    queryStr.append("/%'");
+    queryStr.append(QLatin1String("/%'"));
 
     if (!query.exec(queryStr)) {
-        kError() << "Big query failed:" << query.lastError().text();
+        qWarning() << "Big query failed:" << query.lastError().text();
     }
 
     m_db->sqlDatabase().commit();
     m_db->sqlDatabase().transaction();
 }
-
-#include "metadatamover.moc"
