@@ -29,22 +29,21 @@
 #include <xapian.h>
 #include <QVector>
 #include <QDate>
+#include <QUrl>
+#include <QStandardPaths>
 
-#include <KStandardDirs>
-#include <KDebug>
-#include <KUrl>
-#include <KMimeType>
+#include <QDebug>
+#include <QMimeDatabase>
 
-#include <kfilemetadata/propertyinfo.h>
+#include <KFileMetaData/PropertyInfo>
 
 using namespace Baloo;
 
 FileSearchStore::FileSearchStore(QObject* parent)
     : XapianSearchStore(parent)
-    , m_sqlDb(0)
     , m_sqlMutex(QMutex::Recursive)
 {
-    const QString path = KGlobal::dirs()->localxdgdatadir() + QLatin1String("baloo/file/");
+    const QString path = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1String("/baloo/file/");
     setDbPath(path);
 
     m_prefixes.insert(QLatin1String("filename"), "F");
@@ -57,8 +56,10 @@ FileSearchStore::FileSearchStore(QObject* parent)
 
 FileSearchStore::~FileSearchStore()
 {
-    const QString conName = m_sqlDb->connectionName();
-    delete m_sqlDb;
+    const QString conName = m_sqlDb.connectionName();
+    m_sqlDb.close();
+    m_sqlDb = QSqlDatabase();
+
     QSqlDatabase::removeDatabase(conName);
 }
 
@@ -68,10 +69,9 @@ void FileSearchStore::setDbPath(const QString& path)
 
     const QString conName = QLatin1String("filesearchstore") + QString::number(qrand());
 
-    delete m_sqlDb;
-    m_sqlDb = new QSqlDatabase(QSqlDatabase::addDatabase(QLatin1String("QSQLITE"), conName));
-    m_sqlDb->setDatabaseName(dbPath() + QLatin1String("/fileMap.sqlite3"));
-    m_sqlDb->open();
+    m_sqlDb = QSqlDatabase::addDatabase(QLatin1String("QSQLITE"), conName);
+    m_sqlDb.setDatabaseName(dbPath() + QLatin1String("/fileMap.sqlite3"));
+    m_sqlDb.open();
 }
 
 QStringList FileSearchStore::types()
@@ -213,34 +213,31 @@ QUrl FileSearchStore::constructUrl(const Xapian::docid& docid)
     QMutexLocker lock(&m_sqlMutex);
 
     FileMapping file(docid);
-    file.fetch(*m_sqlDb);
+    file.fetch(m_sqlDb);
 
     return QUrl::fromLocalFile(file.url());
 }
 
 QString FileSearchStore::text(int queryId)
 {
-    return KUrl(url(queryId)).fileName();
+    return url(queryId).fileName();
 }
 
 QString FileSearchStore::icon(int queryId)
 {
-    KMimeType::Ptr mime = KMimeType::findByUrl(url(queryId));
-    return mime->iconName();
+    return QMimeDatabase().mimeTypeForFile(url(queryId).toLocalFile()).iconName();
 }
 
 
-Xapian::Query FileSearchStore::applyCustomOptions(const Xapian::Query& q, const QVariantHash& options)
+Xapian::Query FileSearchStore::applyCustomOptions(const Xapian::Query& q, const QVariantMap& options)
 {
-    QHash<QString, QVariant>::const_iterator it = options.constFind(QLatin1String("includeFolder"));
+    QMap<QString, QVariant>::const_iterator it = options.constFind(QLatin1String("includeFolder"));
     if (it == options.constEnd()) {
         return q;
     }
 
     QString includeDir = it.value().toString();
 
-    PathFilterPostingSource ps(m_sqlDb, includeDir);
+    PathFilterPostingSource ps(&m_sqlDb, includeDir);
     return andQuery(q, Xapian::Query(&ps));
 }
-
-BALOO_EXPORT_SEARCHSTORE(Baloo::FileSearchStore, "baloo_filesearchstore")
