@@ -20,8 +20,8 @@
  *
  */
 
-#include <KDebug>
-#include <KTempDir>
+#include <QDebug>
+#include <QTemporaryDir>
 #include <QTime>
 #include <QCoreApplication>
 
@@ -34,10 +34,10 @@
 
 int main(int argc, char** argv)
 {
-    KTempDir tempDir;
+    QTemporaryDir tempDir;
 
     Database db;
-    db.setPath(tempDir.name());
+    db.setPath(tempDir.path());
     db.init();
 
     Baloo::FileIndexerConfig config;
