@@ -25,7 +25,7 @@
 #include "xapian.h"
 #include "../search/email/agepostingsource.h"
 
-#include <KStandardDirs>
+#include <QStandardPaths>
 
 #include <QFile>
 
@@ -54,7 +54,6 @@ class EmailQuery::Private
 
     EmailQuery::OpType opType;
     int limit;
-    bool splitSearchMatchString;
 };
 
 EmailQuery::Private::Private():
@@ -62,8 +61,7 @@ EmailQuery::Private::Private():
     read('0'),
     attachment('0'),
     opType(OpAnd),
-    limit(0),
-    splitSearchMatchString(true)
+    limit(0)
 {
 }
 
@@ -78,11 +76,6 @@ EmailQuery::~EmailQuery()
     delete d;
 }
 
-void EmailQuery::setSplitSearchMatchString(bool split)
-{
-    d->splitSearchMatchString = split;
-}
-
 void EmailQuery::setSearchType(EmailQuery::OpType op)
 {
     d->opType = op;
@@ -190,21 +183,21 @@ void EmailQuery::setRead(bool read)
 
 ResultIterator EmailQuery::exec()
 {
-    const QString dir = KGlobal::dirs()->localxdgdatadir() + QLatin1String("baloo/email/");
+    const QString dir = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1String("/baloo/email/");
     Xapian::Database db;
     try {
         db = Xapian::Database(QFile::encodeName(dir).constData());
     } catch (const Xapian::DatabaseOpeningError&) {
-        kError() << "Xapian Database does not exist at " << dir;
+        qWarning() << "Xapian Database does not exist at " << dir;
         return ResultIterator();
     } catch (const Xapian::DatabaseCorruptError&) {
-        kError() << "Xapian Database corrupted";
+        qWarning() << "Xapian Database corrupted";
         return ResultIterator();
     } catch (const Xapian::DatabaseError& e) {
-        kWarning() << "Failed to open Xapian database:" << QString::fromStdString(e.get_error_string());
+        qWarning() << "Failed to open Xapian database:" << QString::fromStdString(e.get_error_string());
         return ResultIterator();
     } catch (...) {
-        kError() << "Random exception, but we do not want to crash";
+        qWarning() << "Random exception, but we do not want to crash";
         return ResultIterator();
     }
 
@@ -316,15 +309,10 @@ ResultIterator EmailQuery::exec()
         Xapian::QueryParser parser;
         parser.set_database(db);
         parser.set_default_op(Xapian::Query::OP_AND);
-        if (d->splitSearchMatchString) {
-            const QStringList list = d->matchString.split(QRegExp(QLatin1String("\\s")), QString::SkipEmptyParts);
-            Q_FOREACH (const QString& s, list) {
-                const QByteArray ba = s.toUtf8();
-                m_queries << parser.parse_query(ba.constData(),
-                                                Xapian::QueryParser::FLAG_PARTIAL);
-            }
-        } else {
-            const QByteArray ba = d->matchString.toUtf8();
+
+        const QStringList list = d->matchString.split(QRegExp(QLatin1String("\\s")), QString::SkipEmptyParts);
+        Q_FOREACH (const QString& s, list) {
+            const QByteArray ba = s.toUtf8();
             m_queries << parser.parse_query(ba.constData(),
                                             Xapian::QueryParser::FLAG_PARTIAL);
         }
@@ -356,7 +344,7 @@ ResultIterator EmailQuery::exec()
         return iter;
     }
     catch (const Xapian::Error &e) {
-        kWarning() << QString::fromStdString(e.get_type()) << QString::fromStdString(e.get_description());
+        qWarning() << QString::fromStdString(e.get_type()) << QString::fromStdString(e.get_description());
         return ResultIterator();
     }
 }
